@@ -34,16 +34,14 @@ public enum ConfigurableProperty {
     THANKS_URL("pdfsam.thanks.url"),
     TRACKER_URL("pdfsam.tracker.url"),
     SUPPORT_URL("pdfsam.support.url"),
-    QUICKSTART_URL("pdfsam.quickstart.url"),
+    DOCUMENTATION_URL("pdfsam.documentation.url"),
     TWITTER_URL("pdfsam.twitter.url"),
     FACEBOOK_URL("pdfsam.facebook.url"),
-    GPLUS_URL("pdfsam.gplus.url"),
     TRANSLATE_URL("pdfsam.translate.url"),
     SCM_URL("pdfsam.scm.url"),
     DONATE_URL("pdfsam.donate.url"),
     TWEETER_SHARE_URL("pdfsam.tweeter.share.url"),
     FACEBOOK_SHARE_URL("pdfsam.facebook.share.url"),
-    GPLUS_SHARE_URL("pdfsam.gplus.share.url"),
     NEWS_URL("pdfsam.news.url"),
     PREMIUM_MODULES_URL("pdfsam.premium.modules.url"),
     DOWNLOAD_URL("pdfsam.download.url");
