@@ -25,5 +25,9 @@ package org.pdfsam.ui.commons;
  * 
  */
 public class ShowStageRequest {
-    // nothing
+    public static final ShowStageRequest INSTANCE = new ShowStageRequest();
+
+    private ShowStageRequest() {
+        // hide
+    }
 }
