@@ -24,8 +24,8 @@ import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.ui.commons.ShowStageRequest;
 import org.pdfsam.ui.support.Style;
 
-import de.jensd.fx.glyphs.GlyphsDude;
 import de.jensd.fx.glyphs.fontawesome.FontAwesomeIcon;
+import de.jensd.fx.glyphs.fontawesome.utils.FontAwesomeIconFactory;
 import javafx.scene.control.Button;
 
 /**
@@ -40,9 +40,9 @@ class TaskFailedButton extends Button {
         getStyleClass().addAll(Style.FOOTER_BUTTON.css());
         getStyleClass().add("footer-failed-button");
         setText(DefaultI18nContext.getInstance().i18n("Show errors"));
-        GlyphsDude.setIcon(this, FontAwesomeIcon.TIMES_CIRCLE, "1.6em");
+        FontAwesomeIconFactory.get().setIcon(this, FontAwesomeIcon.TIMES_CIRCLE, "1.6em");
         setMaxHeight(Double.MAX_VALUE);
         setPrefHeight(Double.MAX_VALUE);
-        setOnAction(e -> eventStudio().broadcast(new ShowStageRequest(), "LogStage"));
+        setOnAction(e -> eventStudio().broadcast(ShowStageRequest.INSTANCE, "LogStage"));
     }
 }
