@@ -22,6 +22,8 @@ import static java.util.Arrays.stream;
 import static java.util.Optional.of;
 import static java.util.Optional.ofNullable;
 import static org.apache.commons.lang3.StringUtils.defaultString;
+import static org.pdfsam.support.EncryptionUtils.encrypt;
+import static org.pdfsam.support.io.ObjectCollectionWriter.writeContent;
 import static org.pdfsam.ui.commons.SetDestinationRequest.requestDestination;
 import static org.pdfsam.ui.commons.SetDestinationRequest.requestFallbackDestination;
 import static org.pdfsam.ui.selection.multiple.SelectionChangedEvent.clearSelectionEvent;
@@ -49,6 +51,7 @@ import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.module.ModuleOwned;
 import org.pdfsam.pdf.PdfDocumentDescriptor;
 import org.pdfsam.pdf.PdfLoadRequestEvent;
+import org.pdfsam.support.EncryptionUtils;
 import org.pdfsam.support.io.FileType;
 import org.pdfsam.ui.commons.ClearModuleEvent;
 import org.pdfsam.ui.commons.OpenFileRequest;
@@ -68,10 +71,8 @@ import org.sejda.eventstudio.annotation.EventStation;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import de.jensd.fx.glyphs.GlyphIcons;
-import de.jensd.fx.glyphs.GlyphsDude;
 import de.jensd.fx.glyphs.materialdesignicons.MaterialDesignIcon;
-import de.jensd.fx.glyphs.materialicons.MaterialIcon;
+import de.jensd.fx.glyphs.materialdesignicons.utils.MaterialDesignIconFactory;
 import javafx.application.Platform;
 import javafx.collections.ListChangeListener.Change;
 import javafx.collections.ObservableList;
@@ -84,6 +85,7 @@ import javafx.scene.control.SelectionMode;
 import javafx.scene.control.SeparatorMenuItem;
 import javafx.scene.control.TableRow;
 import javafx.scene.control.TableView;
+import javafx.scene.input.Clipboard;
 import javafx.scene.input.ClipboardContent;
 import javafx.scene.input.DataFormat;
 import javafx.scene.input.DragEvent;
@@ -151,7 +153,7 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
 
     private void initTopSectionContextMenu(ContextMenu contextMenu, boolean hasRanges) {
         MenuItem setDestinationItem = createMenuItem(DefaultI18nContext.getInstance().i18n("Set destination"),
-                MaterialIcon.FLIGHT_LAND);
+                MaterialDesignIcon.AIRPLANE_LANDING);
         setDestinationItem.setOnAction(e -> eventStudio().broadcast(
                 requestDestination(getSelectionModel().getSelectedItem().descriptor().getFile(), getOwnerModule()),
                 getOwnerModule()));
@@ -162,7 +164,7 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
 
         if (hasRanges) {
             MenuItem setPageRangesItem = createMenuItem(DefaultI18nContext.getInstance().i18n("Set as range for all"),
-                    MaterialIcon.TOC);
+                    MaterialDesignIcon.FORMAT_INDENT_INCREASE);
             setPageRangesItem.setOnAction(e -> eventStudio().broadcast(
                     new SetPageRangesRequest(getSelectionModel().getSelectedItem().pageSelection.get()),
                     getOwnerModule()));
@@ -220,7 +222,7 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
         }
         if (canDuplicate) {
             MenuItem duplicateItem = createMenuItem(DefaultI18nContext.getInstance().i18n("Duplicate"),
-                    MaterialDesignIcon.CONTENT_COPY);
+                    MaterialDesignIcon.CONTENT_DUPLICATE);
             duplicateItem.setOnAction(e -> eventStudio().broadcast(new DuplicateSelectedEvent(), getOwnerModule()));
             duplicateItem.setAccelerator(new KeyCodeCombination(KeyCode.DIGIT2, KeyCombination.ALT_DOWN));
 
@@ -233,6 +235,10 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
 
     private void initBottomSectionContextMenu(ContextMenu contextMenu) {
 
+        MenuItem copyItem = createMenuItem(DefaultI18nContext.getInstance().i18n("Copy to clipboard"),
+                MaterialDesignIcon.CONTENT_COPY);
+        copyItem.setOnAction(e -> copySelectedToClipboard());
+
         MenuItem infoItem = createMenuItem(DefaultI18nContext.getInstance().i18n("Document properties"),
                 MaterialDesignIcon.INFORMATION_OUTLINE);
         infoItem.setOnAction(e -> Platform.runLater(() -> eventStudio()
@@ -248,23 +254,25 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
         openFolderItem.setOnAction(e -> eventStudio().broadcast(
                 new OpenFileRequest(getSelectionModel().getSelectedItem().descriptor().getFile().getParentFile())));
 
+        copyItem.setAccelerator(new KeyCodeCombination(KeyCode.C, KeyCombination.SHORTCUT_DOWN));
         infoItem.setAccelerator(new KeyCodeCombination(KeyCode.P, KeyCombination.ALT_DOWN));
         openFileItem.setAccelerator(new KeyCodeCombination(KeyCode.O, KeyCombination.SHORTCUT_DOWN));
         openFolderItem.setAccelerator(
                 new KeyCodeCombination(KeyCode.O, KeyCombination.SHORTCUT_DOWN, KeyCombination.ALT_DOWN));
 
-        contextMenu.getItems().addAll(new SeparatorMenuItem(), infoItem, openFileItem, openFolderItem);
+        contextMenu.getItems().addAll(new SeparatorMenuItem(), copyItem, infoItem, openFileItem, openFolderItem);
 
         selectionChangedConsumer = selectionChangedConsumer.andThen(e -> {
+            copyItem.setDisable(e.isClearSelection());
             infoItem.setDisable(!e.isSingleSelection());
             openFileItem.setDisable(!e.isSingleSelection());
             openFolderItem.setDisable(!e.isSingleSelection());
         });
     }
 
-    private MenuItem createMenuItem(String text, GlyphIcons icon) {
+    private MenuItem createMenuItem(String text, MaterialDesignIcon icon) {
         MenuItem item = new MenuItem(text);
-        GlyphsDude.setIcon(item, icon, "1.1em");
+        MaterialDesignIconFactory.get().setIcon(item, icon, "1.1em");
         item.setDisable(true);
         return item;
     }
@@ -474,6 +482,15 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
         }
     }
 
+    private void copySelectedToClipboard() {
+        ClipboardContent content = new ClipboardContent();
+        writeContent(getSelectionModel().getSelectedItems().stream().map(item -> {
+            return item.descriptor().getFile().getAbsolutePath() + ", " + item.descriptor().getFile().length() + ", "
+                    + item.descriptor().pages().getValue();
+        }).collect(Collectors.toList())).to(content);
+        Clipboard.getSystemClipboard().setContent(content);
+    }
+
     @Override
     public void saveStateTo(Map<String, String> data) {
         data.put(defaultString(getId()) + "input.size", Integer.toString(getItems().size()));
@@ -482,7 +499,7 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
             String id = defaultString(getId());
             data.put(id + "input." + i, current.descriptor().getFile().getAbsolutePath());
             if (new DefaultUserContext().isSavePwdInWorkspaceFile()) {
-                data.put(id + "input.password." + i, current.descriptor().getPassword());
+                data.put(id + "input.password.enc" + i, encrypt(current.descriptor().getPassword()));
             }
             data.put(id + "input.range." + i, defaultString(current.pageSelection.get()));
             data.put(id + "input.step." + i, defaultString(current.pace.get()));
@@ -501,7 +518,8 @@ public class SelectionTable extends TableView<SelectionTableRowData> implements
                 String id = defaultString(getId());
                 Optional.ofNullable(data.get(id + "input." + i)).ifPresent(f -> {
                     PdfDocumentDescriptor descriptor = PdfDocumentDescriptor.newDescriptor(new File(f),
-                            data.get(id + "input.password." + i));
+                            ofNullable(data.get(id + "input.password.enc" + i)).map(EncryptionUtils::decrypt)
+                                    .orElseGet(() -> data.get(defaultString(getId()) + "input.password." + i)));
                     loadEvent.add(descriptor);
                     SelectionTableRowData row = new SelectionTableRowData(descriptor);
                     row.pageSelection.set(data.get(id + "input.range." + i));
