@@ -19,6 +19,7 @@
 package org.pdfsam.ui.selection.single;
 
 import static java.util.Objects.nonNull;
+import static java.util.Optional.ofNullable;
 import static org.apache.commons.lang3.StringUtils.EMPTY;
 import static org.apache.commons.lang3.StringUtils.defaultString;
 import static org.apache.commons.lang3.StringUtils.isEmpty;
@@ -26,6 +27,7 @@ import static org.pdfsam.pdf.PdfDescriptorLoadingStatus.ENCRYPTED;
 import static org.pdfsam.pdf.PdfDescriptorLoadingStatus.WITH_ERRORS;
 import static org.pdfsam.pdf.PdfDocumentDescriptor.newDescriptor;
 import static org.pdfsam.pdf.PdfDocumentDescriptor.newDescriptorNoPassword;
+import static org.pdfsam.support.EncryptionUtils.encrypt;
 import static org.pdfsam.ui.commons.SetDestinationRequest.requestDestination;
 import static org.pdfsam.ui.commons.SetDestinationRequest.requestFallbackDestination;
 import static org.sejda.eventstudio.StaticStudio.eventStudio;
@@ -43,6 +45,7 @@ import org.pdfsam.pdf.PdfDescriptorLoadingStatus;
 import org.pdfsam.pdf.PdfDocumentDescriptor;
 import org.pdfsam.pdf.PdfDocumentDescriptorProvider;
 import org.pdfsam.pdf.PdfLoadRequestEvent;
+import org.pdfsam.support.EncryptionUtils;
 import org.pdfsam.support.io.FileType;
 import org.pdfsam.ui.commons.ClearModuleEvent;
 import org.pdfsam.ui.commons.OpenFileRequest;
@@ -59,10 +62,8 @@ import org.pdfsam.ui.workspace.RestorableView;
 import org.sejda.eventstudio.annotation.EventListener;
 import org.sejda.eventstudio.annotation.EventStation;
 
-import de.jensd.fx.glyphs.GlyphIcons;
-import de.jensd.fx.glyphs.GlyphsDude;
 import de.jensd.fx.glyphs.materialdesignicons.MaterialDesignIcon;
-import de.jensd.fx.glyphs.materialicons.MaterialIcon;
+import de.jensd.fx.glyphs.materialdesignicons.utils.MaterialDesignIconFactory;
 import javafx.application.Platform;
 import javafx.beans.value.ChangeListener;
 import javafx.beans.value.ObservableValue;
@@ -117,7 +118,7 @@ public class SingleSelectionPane extends VBox implements ModuleOwned, PdfDocumen
         }
     };
 
-    private Consumer<PdfDocumentDescriptor> encryptionIndicatorUpdate = new Consumer<PdfDocumentDescriptor>() {
+    private Consumer<PdfDocumentDescriptor> encryptionIndicatorUpdate = new Consumer<>() {
         private LoadingStatusIndicatorUpdater updater = new LoadingStatusIndicatorUpdater(encryptionIndicator);
 
         @Override
@@ -138,7 +139,7 @@ public class SingleSelectionPane extends VBox implements ModuleOwned, PdfDocumen
         }
     };
 
-    private ToggleChangeListener<? super ValidationState> onValidState = new ToggleChangeListener<ValidationState>() {
+    private ToggleChangeListener<? super ValidationState> onValidState = new ToggleChangeListener<>() {
 
         @Override
         public void onChanged(ObservableValue<? extends ValidationState> observable, ValidationState oldValue,
@@ -162,7 +163,7 @@ public class SingleSelectionPane extends VBox implements ModuleOwned, PdfDocumen
             if (descriptor.loadingStatus().getValue() == ENCRYPTED) {
                 showPasswordFieldPopup();
             } else if (descriptor.loadingStatus().getValue() == WITH_ERRORS) {
-                eventStudio().broadcast(new ShowStageRequest(), "LogStage");
+                eventStudio().broadcast(ShowStageRequest.INSTANCE, "LogStage");
             }
         });
         HBox.setMargin(encryptionIndicator, new Insets(0, 0, 0, 2));
@@ -235,7 +236,7 @@ public class SingleSelectionPane extends VBox implements ModuleOwned, PdfDocumen
         if (descriptor != null) {
             data.put(defaultString(getId()) + "input", descriptor.getFile().getAbsolutePath());
             if (new DefaultUserContext().isSavePwdInWorkspaceFile()) {
-                data.put(defaultString(getId()) + "input.password", descriptor.getPassword());
+                data.put(defaultString(getId()) + "input.password.enc", encrypt(descriptor.getPassword()));
             }
         }
     }
@@ -247,7 +248,9 @@ public class SingleSelectionPane extends VBox implements ModuleOwned, PdfDocumen
             onValidState.disabled(true);
             getField().getTextField().setText(f);
             onValidState.disabled(false);
-            initializeFor(newDescriptor(new File(f), data.get(defaultString(getId()) + "input.password")));
+            initializeFor(newDescriptor(new File(f),
+                    ofNullable(data.get(defaultString(getId()) + "input.password.enc")).map(EncryptionUtils::decrypt)
+                            .orElseGet(() -> data.get(defaultString(getId()) + "input.password"))));
         });
     }
 
@@ -271,7 +274,7 @@ public class SingleSelectionPane extends VBox implements ModuleOwned, PdfDocumen
         removeSelected.setOnAction(e -> eventStudio().broadcast(new ClearModuleEvent(), getOwnerModule()));
 
         MenuItem setDestinationItem = createMenuItem(DefaultI18nContext.getInstance().i18n("Set destination"),
-                MaterialIcon.FLIGHT_LAND);
+                MaterialDesignIcon.AIRPLANE_LANDING);
         setDestinationItem.setAccelerator(new KeyCodeCombination(KeyCode.O, KeyCombination.ALT_DOWN));
         setDestinationItem.setOnAction(e -> eventStudio()
                 .broadcast(requestDestination(descriptor.getFile(), getOwnerModule()), getOwnerModule()));
@@ -301,9 +304,9 @@ public class SingleSelectionPane extends VBox implements ModuleOwned, PdfDocumen
                 .ifPresent(field::setTextFromFile);
     }
 
-    private MenuItem createMenuItem(String text, GlyphIcons icon) {
+    private MenuItem createMenuItem(String text, MaterialDesignIcon icon) {
         MenuItem item = new MenuItem(text);
-        GlyphsDude.setIcon(item, icon, "1.1em");
+        MaterialDesignIconFactory.get().setIcon(item, icon, "1.1em");
         item.setDisable(true);
         return item;
     }
