@@ -30,6 +30,9 @@ import javafx.application.Platform;
 import javafx.scene.control.ContextMenu;
 import javafx.scene.control.MenuItem;
 import javafx.scene.control.SeparatorMenuItem;
+import javafx.scene.input.KeyCode;
+import javafx.scene.input.KeyCodeCombination;
+import javafx.scene.input.KeyCombination;
 
 /**
  * Context menu showing app functionalities. This is supposed to be activated by the menu button
@@ -42,9 +45,16 @@ class AppContextMenu extends ContextMenu {
     AppContextMenu(WorkspaceMenu workspace, ModulesMenu modulesMenu) {
         MenuItem exit = new MenuItem(DefaultI18nContext.getInstance().i18n("E_xit"));
         exit.setOnAction(e -> Platform.exit());
-        MenuItem settings = new MenuItem(DefaultI18nContext.getInstance().i18n("_Settings"));
-        settings.setOnAction(
-                e -> eventStudio().broadcast(new SetActiveDashboardItemRequest(PreferencesDashboardItem.ID)));
-        getItems().addAll(workspace, modulesMenu, settings, new SeparatorMenuItem(), exit);
+        exit.setAccelerator(new KeyCodeCombination(KeyCode.Q, KeyCombination.SHORTCUT_DOWN));
+        getItems().addAll(workspace, modulesMenu);
+        if (!Boolean.getBoolean(PreferencesDashboardItem.PDFSAM_DISABLE_SETTINGS_DEPRECATED)
+                && !Boolean.getBoolean(PreferencesDashboardItem.PDFSAM_DISABLE_SETTINGS)) {
+            MenuItem settings = new MenuItem(DefaultI18nContext.getInstance().i18n("_Settings"));
+            settings.setOnAction(
+                    e -> eventStudio().broadcast(new SetActiveDashboardItemRequest(PreferencesDashboardItem.ID)));
+            getItems().add(settings);
+        }
+
+        getItems().addAll(new SeparatorMenuItem(), exit);
     }
 }
