@@ -19,15 +19,14 @@
 package org.pdfsam.ui.dashboard.about;
 
 import static org.pdfsam.ConfigurableProperty.COPYRIGHT;
+import static org.pdfsam.ConfigurableProperty.DOCUMENTATION_URL;
 import static org.pdfsam.ConfigurableProperty.DONATE_URL;
 import static org.pdfsam.ConfigurableProperty.FACEBOOK_URL;
 import static org.pdfsam.ConfigurableProperty.FEED_URL;
-import static org.pdfsam.ConfigurableProperty.GPLUS_URL;
 import static org.pdfsam.ConfigurableProperty.HOME_LABEL;
 import static org.pdfsam.ConfigurableProperty.HOME_URL;
 import static org.pdfsam.ConfigurableProperty.LICENSE_NAME;
 import static org.pdfsam.ConfigurableProperty.LICENSE_URL;
-import static org.pdfsam.ConfigurableProperty.QUICKSTART_URL;
 import static org.pdfsam.ConfigurableProperty.SCM_URL;
 import static org.pdfsam.ConfigurableProperty.SUPPORT_URL;
 import static org.pdfsam.ConfigurableProperty.TRACKER_URL;
@@ -46,8 +45,8 @@ import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.ui.commons.UrlButton;
 import org.pdfsam.ui.support.Style;
 
-import de.jensd.fx.glyphs.GlyphsDude;
 import de.jensd.fx.glyphs.fontawesome.FontAwesomeIcon;
+import de.jensd.fx.glyphs.fontawesome.utils.FontAwesomeIconFactory;
 import javafx.scene.control.Button;
 import javafx.scene.control.Label;
 import javafx.scene.input.Clipboard;
@@ -70,7 +69,7 @@ public class AboutDashboardPane extends HBox {
         VBox left = new VBox(5);
         addSectionTitle(pdfsam.name(), left);
         Label copyright = new Label(pdfsam.property(COPYRIGHT));
-        GlyphsDude.setIcon(copyright, FontAwesomeIcon.COPYRIGHT);
+        FontAwesomeIconFactory.get().setIcon(copyright, FontAwesomeIcon.COPYRIGHT);
         left.getChildren().addAll(new Label(String.format("ver. %s", pdfsam.property(VERSION))), copyright);
         addHyperlink(null, pdfsam.property(LICENSE_URL), pdfsam.property(LICENSE_NAME), left);
         addHyperlink(FontAwesomeIcon.HOME, pdfsam.property(HOME_URL), pdfsam.property(HOME_LABEL), left);
@@ -80,10 +79,14 @@ public class AboutDashboardPane extends HBox {
         addSectionTitle(DefaultI18nContext.getInstance().i18n("Environment"), left);
         Label runtime = new Label(String.format("%s %s", System.getProperty("java.runtime.name"),
                 System.getProperty("java.runtime.version")));
+        Label runtimePath = new Label(String.format(DefaultI18nContext.getInstance().i18n("Java runtime path: %s"),
+                System.getProperty("java.home")));
+        Label fx = new Label(String.format(DefaultI18nContext.getInstance().i18n("JavaFX runtime version %s"),
+                System.getProperty("javafx.runtime.version")));
         Label memory = new Label(DefaultI18nContext.getInstance().i18n("Max memory {0}",
                 FileUtils.byteCountToDisplaySize(Runtime.getRuntime().maxMemory())));
         Button copyButton = new Button(DefaultI18nContext.getInstance().i18n("Copy to clipboard"));
-        GlyphsDude.setIcon(copyButton, FontAwesomeIcon.COPY);
+        FontAwesomeIconFactory.get().setIcon(copyButton, FontAwesomeIcon.COPY);
         copyButton.getStyleClass().addAll(Style.BUTTON.css());
         copyButton.setId("copyEnvDetails");
         copyButton.setOnAction(a -> {
@@ -92,7 +95,7 @@ public class AboutDashboardPane extends HBox {
                     .to(content);
             Clipboard.getSystemClipboard().setContent(content);
         });
-        left.getChildren().addAll(runtime, memory, copyButton);
+        left.getChildren().addAll(runtime, runtimePath, fx, memory, copyButton);
 
         VBox right = new VBox(5);
         addSectionTitle(DefaultI18nContext.getInstance().i18n("Support"), right);
@@ -100,8 +103,8 @@ public class AboutDashboardPane extends HBox {
                 DefaultI18nContext.getInstance().i18n("Bug and feature requests"), right);
         addHyperlink(FontAwesomeIcon.QUESTION_CIRCLE, pdfsam.property(SUPPORT_URL),
                 DefaultI18nContext.getInstance().i18n("Support"), right);
-        addHyperlink(FontAwesomeIcon.YOUTUBE_PLAY, pdfsam.property(QUICKSTART_URL),
-                DefaultI18nContext.getInstance().i18n("Play the \"get started\" video"), right);
+        addHyperlink(FontAwesomeIcon.BOOK, pdfsam.property(DOCUMENTATION_URL),
+                DefaultI18nContext.getInstance().i18n("Documentation"), right);
 
         addSectionTitle(DefaultI18nContext.getInstance().i18n("Contribute"), right);
         addHyperlink(FontAwesomeIcon.GITHUB, pdfsam.property(SCM_URL),
@@ -114,8 +117,6 @@ public class AboutDashboardPane extends HBox {
         addSectionTitle(DefaultI18nContext.getInstance().i18n("Social"), right);
         addHyperlink(FontAwesomeIcon.TWITTER_SQUARE, pdfsam.property(TWITTER_URL),
                 DefaultI18nContext.getInstance().i18n("Follow us on Twitter"), right);
-        addHyperlink(FontAwesomeIcon.GOOGLE_PLUS_SQUARE, pdfsam.property(GPLUS_URL),
-                DefaultI18nContext.getInstance().i18n("Follow us on Google Plus"), right);
         addHyperlink(FontAwesomeIcon.FACEBOOK_SQUARE, pdfsam.property(FACEBOOK_URL),
                 DefaultI18nContext.getInstance().i18n("Like us on Facebook"), right);
         getChildren().addAll(left, right);
