@@ -21,10 +21,12 @@ package org.pdfsam.ui.notification;
 import static org.pdfsam.ui.commons.UrlButton.styledUrlButton;
 import static org.sejda.eventstudio.StaticStudio.eventStudio;
 
+import java.nio.file.AccessDeniedException;
 import java.security.SecureRandom;
 
 import javax.inject.Inject;
 
+import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.pdfsam.ConfigurableProperty;
 import org.pdfsam.Pdfsam;
 import org.pdfsam.context.UserContext;
@@ -97,6 +99,13 @@ public class NotificationsController {
                                     .i18n("Input parameters are invalid, open the application messages for details."),
                             NotificationType.ERROR));
         }
+        Throwable root = ExceptionUtils.getRootCause(e.getFailingCause());
+        if (root instanceof AccessDeniedException) {
+            container.addNotification(DefaultI18nContext.getInstance().i18n("Access denied"),
+                    buildLabel(DefaultI18nContext.getInstance().i18n(
+                            "Unable to access \"{0}\", please make sure you have write permissions or open the application messages for details.",
+                            ((AccessDeniedException) root).getFile()), NotificationType.ERROR));
+        }
     }
 
     @EventListener
@@ -129,8 +138,6 @@ public class NotificationsController {
                 buildLabel(DefaultI18nContext.getInstance().i18n("You performed {0} tasks with PDFsam, did it help?",
                         Long.toString(usages)), NotificationType.SHARE),
                 new HBox(3, spacer,
-                        styledUrlButton(null, pdfsam.property(ConfigurableProperty.GPLUS_SHARE_URL),
-                                FontAwesomeIcon.GOOGLE_PLUS),
                         styledUrlButton(null, pdfsam.property(ConfigurableProperty.FACEBOOK_SHARE_URL),
                                 FontAwesomeIcon.FACEBOOK),
                         styledUrlButton(DefaultI18nContext.getInstance().i18n("Spread the word!"),
