@@ -21,40 +21,50 @@ package org.pdfsam.ui.banner;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.verify;
 import static org.sejda.eventstudio.StaticStudio.eventStudio;
 
 import org.junit.Test;
-import org.junit.experimental.categories.Category;
-import org.loadui.testfx.GuiTest;
-import org.loadui.testfx.categories.TestFX;
+import org.pdfsam.news.HideNewsPanelRequest;
 import org.pdfsam.news.ShowNewsPanelRequest;
 import org.sejda.eventstudio.Listener;
+import org.testfx.framework.junit.ApplicationTest;
 
-import javafx.scene.Parent;
+import javafx.scene.Scene;
+import javafx.stage.Stage;
 
 /**
  * @author Andrea Vacondio
  */
-@Category(TestFX.class)
-public class NewsButtonTest extends GuiTest {
+public class NewsButtonTest extends ApplicationTest {
+    private NewsButton victim;
+
     @Override
-    protected Parent getRootNode() {
-        return new NewsButton();
+    public void start(Stage stage) {
+        victim = new NewsButton();
+        Scene scene = new Scene(victim);
+        stage.setScene(scene);
+        stage.show();
     }
 
     @Test
     public void onClick() {
         Listener<ShowNewsPanelRequest> listener = mock(Listener.class);
+        Listener<HideNewsPanelRequest> hideListener = mock(Listener.class);
         eventStudio().add(ShowNewsPanelRequest.class, listener);
-        click(".button");
-        verify(listener).onEvent(any());
+        eventStudio().add(HideNewsPanelRequest.class, hideListener);
+        clickOn(".button");
+        verify(listener).onEvent(eq(ShowNewsPanelRequest.INSTANCE));
+        verify(hideListener, never()).onEvent(any());
+        clickOn(".button");
+        verify(hideListener).onEvent(eq(HideNewsPanelRequest.INSTANCE));
     }
 
     @Test
     public void setUpToDate() {
-        NewsButton victim = find(".button");
         assertFalse(victim.getStyleClass().contains(NewsButton.UP_TO_DATE_CSS_CLASS));
         victim.setUpToDate(false);
         assertTrue(victim.getStyleClass().contains(NewsButton.UP_TO_DATE_CSS_CLASS));
