@@ -27,35 +27,34 @@ import java.io.File;
 
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.experimental.categories.Category;
 import org.junit.rules.TemporaryFolder;
-import org.loadui.testfx.GuiTest;
-import org.loadui.testfx.categories.TestFX;
-import org.loadui.testfx.utils.FXTestUtils;
 import org.pdfsam.context.StringUserPreference;
 import org.pdfsam.context.UserContext;
-import org.pdfsam.ui.commons.ValidableTextField;
+import org.testfx.framework.junit.ApplicationTest;
 
-import javafx.scene.Parent;
+import javafx.scene.Scene;
 import javafx.scene.input.KeyCode;
+import javafx.scene.layout.HBox;
+import javafx.stage.Stage;
 
 /**
  * @author Andrea Vacondio
  *
  */
-@Category(TestFX.class)
-public class PreferenceBrowsableDirectoryFieldTest extends GuiTest {
+public class PreferenceBrowsableDirectoryFieldTest extends ApplicationTest {
 
     @Rule
     public TemporaryFolder folder = new TemporaryFolder();
     private UserContext userContext = mock(UserContext.class);
 
     @Override
-    protected Parent getRootNode() {
+    public void start(Stage stage) {
         PreferenceBrowsableDirectoryField victim = new PreferenceBrowsableDirectoryField(
                 StringUserPreference.WORKING_PATH, userContext);
         victim.setId("victim");
-        return victim;
+        Scene scene = new Scene(new HBox(victim));
+        stage.setScene(scene);
+        stage.show();
     }
 
     @Test
@@ -73,21 +72,18 @@ public class PreferenceBrowsableDirectoryFieldTest extends GuiTest {
     }
 
     @Test
-    public void emptyValue() throws Exception {
+    public void emptyValue() {
         typePathAndValidate("");
         verify(userContext).setStringPreference(StringUserPreference.WORKING_PATH, "");
     }
 
     @Test
-    public void blankValue() throws Exception {
+    public void blankValue() {
         typePathAndValidate("  ");
         verify(userContext, never()).setStringPreference(any(), any());
     }
 
-    private void typePathAndValidate(String path) throws Exception {
-        ValidableTextField field = find(".validable-container-field");
-        // TODO replace with typing when slash works
-        FXTestUtils.invokeAndWait(() -> field.setText(path), 2);
-        click(field).type(KeyCode.TAB);
+    private void typePathAndValidate(String path) {
+        clickOn(".validable-container-field").write(path).push(KeyCode.TAB);
     }
 }
