@@ -32,10 +32,7 @@ import java.util.Locale;
 import org.junit.BeforeClass;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.experimental.categories.Category;
 import org.junit.rules.TemporaryFolder;
-import org.loadui.testfx.GuiTest;
-import org.loadui.testfx.categories.TestFX;
 import org.pdfsam.configuration.StylesConfig;
 import org.pdfsam.i18n.DefaultI18nContext;
 import org.pdfsam.i18n.SetLocaleEvent;
@@ -44,21 +41,24 @@ import org.pdfsam.ui.commons.NonExistingOutputDirectoryEvent;
 import org.sejda.injector.Components;
 import org.sejda.injector.Injector;
 import org.sejda.injector.Provides;
+import org.testfx.framework.junit.ApplicationTest;
 
-import javafx.scene.Parent;
+import javafx.scene.Scene;
 import javafx.scene.control.Button;
+import javafx.scene.layout.VBox;
+import javafx.stage.Stage;
 
 /**
  * @author Andrea Vacondio
  *
  */
-@Category(TestFX.class)
-public class CreateOutputDirectoryDialogControllerTest extends GuiTest {
+public class CreateOutputDirectoryDialogControllerTest extends ApplicationTest {
     @Rule
     public ClearEventStudioRule clearEventStudio = new ClearEventStudioRule();
 
     @Rule
     public TemporaryFolder folder = new TemporaryFolder();
+    private Button button;
 
     @BeforeClass
     public static void setUp() {
@@ -66,10 +66,12 @@ public class CreateOutputDirectoryDialogControllerTest extends GuiTest {
     }
 
     @Override
-    protected Parent getRootNode() {
+    public void start(Stage stage) {
         Injector.start(new Config());
-        Button button = new Button("show");
-        return button;
+        button = new Button("show");
+        Scene scene = new Scene(new VBox(button));
+        stage.setScene(scene);
+        stage.show();
     }
 
     @Components({ CreateOutputDirectoryDialogController.class })
@@ -84,23 +86,21 @@ public class CreateOutputDirectoryDialogControllerTest extends GuiTest {
 
     @Test
     public void negativeTest() throws IOException {
-        Button button = find("show");
         Path file = Paths.get(folder.newFolder().getAbsolutePath());
         button.setOnAction(a -> eventStudio().broadcast(new NonExistingOutputDirectoryEvent(file)));
         folder.delete();
-        click("show");
-        click(DefaultI18nContext.getInstance().i18n("No"));
+        clickOn("show");
+        clickOn(DefaultI18nContext.getInstance().i18n("No"));
         assertFalse(Files.exists(file));
     }
 
     @Test
     public void positiveTest() throws IOException {
-        Button button = find("show");
         Path file = Paths.get(folder.newFolder().getAbsolutePath());
         button.setOnAction(a -> eventStudio().broadcast(new NonExistingOutputDirectoryEvent(file)));
         folder.delete();
-        click("show");
-        click(DefaultI18nContext.getInstance().i18n("Yes"));
+        clickOn("show");
+        clickOn(DefaultI18nContext.getInstance().i18n("Yes"));
         assertTrue(Files.exists(file));
     }
 }
