@@ -32,8 +32,7 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.junit.rules.TemporaryFolder;
-import org.loadui.testfx.GuiTest;
-import org.loadui.testfx.categories.TestFX;
+import org.pdfsam.NoHeadless;
 import org.pdfsam.configuration.StylesConfig;
 import org.pdfsam.module.Module;
 import org.pdfsam.pdf.PdfLoadRequestEvent;
@@ -43,34 +42,40 @@ import org.pdfsam.ui.InputPdfArgumentsLoadRequest;
 import org.pdfsam.ui.commons.ClearModuleEvent;
 import org.pdfsam.ui.commons.SetActiveModuleRequest;
 import org.sejda.eventstudio.Listener;
+import org.testfx.framework.junit.ApplicationTest;
 
-import javafx.scene.Parent;
+import javafx.scene.Scene;
 import javafx.scene.control.Button;
+import javafx.scene.layout.VBox;
+import javafx.stage.Stage;
 
 /**
  * @author Andrea Vacondio
  *
  */
-@Category(TestFX.class)
-public class OpenWithDialogTest extends GuiTest {
+public class OpenWithDialogTest extends ApplicationTest {
 
     @Rule
     public TemporaryFolder folder = new TemporaryFolder();
     private Module module = new DefaultPriorityTestModule();
     @Rule
     public ClearEventStudioRule clearEventStudio = new ClearEventStudioRule(module.id());
+    private Button button;
 
     @Override
-    protected Parent getRootNode() {
+    public void start(Stage stage) {
         StylesConfig styles = mock(StylesConfig.class);
         List<Module> modulesMap = new ArrayList<>();
         modulesMap.add(module);
         new OpenWithDialogController(new OpenWithDialog(styles, modulesMap));
-        Button button = new Button("show");
-        return button;
+        button = new Button("show");
+        Scene scene = new Scene(new VBox(button));
+        stage.setScene(scene);
+        stage.show();
     }
 
     @Test
+    @Category(NoHeadless.class)
     public void singleArg() throws IOException {
         Listener<ClearModuleEvent> clearListener = mock(Listener.class);
         eventStudio().add(ClearModuleEvent.class, clearListener, module.id());
@@ -79,12 +84,11 @@ public class OpenWithDialogTest extends GuiTest {
         Listener<PdfLoadRequestEvent> loadRequestListener = mock(Listener.class);
         eventStudio().add(PdfLoadRequestEvent.class, loadRequestListener, module.id());
 
-        Button button = find("show");
         InputPdfArgumentsLoadRequest event = new InputPdfArgumentsLoadRequest();
         event.pdfs.add(Paths.get(folder.newFile().getAbsolutePath()));
         button.setOnAction(a -> eventStudio().broadcast(event));
-        click("show");
-        click(module.descriptor().getName());
+        clickOn("show");
+        clickOn(module.descriptor().getName());
         verify(clearListener).onEvent(any());
         verify(activeModuleListener).onEvent(any());
         verify(loadRequestListener).onEvent(any());
