@@ -26,6 +26,7 @@ import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
+import java.nio.file.AccessDeniedException;
 import java.util.Collections;
 
 import org.junit.Before;
@@ -42,6 +43,7 @@ import org.pdfsam.test.ClearEventStudioRule;
 import org.pdfsam.test.InitializeAndApplyJavaFxThreadRule;
 import org.pdfsam.update.UpdateAvailableEvent;
 import org.sejda.model.exception.InvalidTaskParametersException;
+import org.sejda.model.exception.TaskIOException;
 import org.sejda.model.notification.event.TaskExecutionCompletedEvent;
 import org.sejda.model.notification.event.TaskExecutionFailedEvent;
 
@@ -70,7 +72,6 @@ public class NotificationsControllerTest {
         when(pdfsam.property(ConfigurableProperty.DONATE_URL)).thenReturn("http://www.pdfsam.org");
         when(pdfsam.property(ConfigurableProperty.TWEETER_SHARE_URL)).thenReturn("http://www.pdfsam.org");
         when(pdfsam.property(ConfigurableProperty.FACEBOOK_SHARE_URL)).thenReturn("http://www.pdfsam.org");
-        when(pdfsam.property(ConfigurableProperty.GPLUS_SHARE_URL)).thenReturn("http://www.pdfsam.org");
         when(context.isDonationNotification()).thenReturn(true);
         victim = new NotificationsController(container, service, pdfsam, context);
     }
@@ -111,6 +112,14 @@ public class NotificationsControllerTest {
         verify(container).addNotification(anyString(), any());
     }
 
+    @Test
+    public void onAccessDenied() {
+        TaskExecutionFailedEvent event = new TaskExecutionFailedEvent(
+                new TaskIOException(new AccessDeniedException("the file")), null);
+        victim.onTaskFailed(event);
+        verify(container).addNotification(anyString(), any());
+    }
+
     @Test
     public void onTaskCompleteAndNoProDisplay() {
         when(service.getTotalUsage()).thenReturn(1L);
