@@ -36,11 +36,7 @@ import java.util.function.Consumer;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.experimental.categories.Category;
 import org.junit.rules.TemporaryFolder;
-import org.loadui.testfx.GuiTest;
-import org.loadui.testfx.categories.TestFX;
-import org.loadui.testfx.utils.FXTestUtils;
 import org.pdfsam.split.SplitByEveryRadioButton.SplitByEveryXPagesParametersBuilder;
 import org.pdfsam.test.ClearEventStudioRule;
 import org.pdfsam.ui.commons.ValidableTextField;
@@ -50,23 +46,25 @@ import org.sejda.model.output.ExistingOutputPolicy;
 import org.sejda.model.output.FileOrDirectoryTaskOutput;
 import org.sejda.model.parameter.SplitByEveryXPagesParameters;
 import org.sejda.model.pdf.PdfVersion;
+import org.testfx.framework.junit.ApplicationTest;
 
-import javafx.scene.Parent;
+import javafx.scene.Scene;
 import javafx.scene.input.KeyCode;
 import javafx.scene.layout.HBox;
+import javafx.stage.Stage;
 
 /**
  * @author Andrea Vacondio
  *
  */
-@Category(TestFX.class)
-public class SplitByEveryRadioButtonTest extends GuiTest {
+public class SplitByEveryRadioButtonTest extends ApplicationTest {
 
     @Rule
     public ClearEventStudioRule clear = new ClearEventStudioRule();
     @Rule
     public TemporaryFolder folder = new TemporaryFolder();
     private Consumer<String> onError;
+    private SplitByEveryRadioButton victim;
 
     @Before
     public void setUp() {
@@ -74,84 +72,80 @@ public class SplitByEveryRadioButtonTest extends GuiTest {
     }
 
     @Override
-    protected Parent getRootNode() {
+    public void start(Stage stage) {
         ValidableTextField field = new ValidableTextField();
         field.setId("field");
-        SplitByEveryRadioButton victim = new SplitByEveryRadioButton(field);
+        victim = new SplitByEveryRadioButton(field);
         victim.setId("victim");
-        return new HBox(victim, field);
+        Scene scene = new Scene(new HBox(victim, field));
+        stage.setScene(scene);
+        stage.show();
     }
 
     @Test
     public void valid() {
-        ValidableTextField field = find("#field");
+        ValidableTextField field = lookup("#field").queryAs(ValidableTextField.class);
         assertEquals(ValidationState.NOT_VALIDATED, field.getValidationState());
-        click(field).type("2").push(KeyCode.ENTER);
+        clickOn(field).type(KeyCode.DIGIT2).push(KeyCode.ENTER);
         assertEquals(ValidationState.VALID, field.getValidationState());
     }
 
     @Test
     public void invalid() {
-        ValidableTextField field = find("#field");
+        ValidableTextField field = lookup("#field").queryAs(ValidableTextField.class);
         assertEquals(ValidationState.NOT_VALIDATED, field.getValidationState());
-        click(field).type("Chuck").push(KeyCode.ENTER);
+        clickOn(field).write("Chuck").push(KeyCode.ENTER);
         assertEquals(ValidationState.INVALID, field.getValidationState());
     }
 
     @Test
     public void invalidMaxPage() {
-        ValidableTextField field = find("#field");
-        SplitByEveryRadioButton victim = find("#victim");
+        ValidableTextField field = lookup("#field").queryAs(ValidableTextField.class);
         victim.setMaxPages(10);
         assertEquals(ValidationState.NOT_VALIDATED, field.getValidationState());
-        click(field).type("10").push(KeyCode.ENTER);
+        clickOn(field).write("10").push(KeyCode.ENTER);
         assertEquals(ValidationState.INVALID, field.getValidationState());
     }
 
     @Test
-    public void invalidBuilder() throws Exception {
-        ValidableTextField field = find("#field");
-        SplitByEveryRadioButton victim = find("#victim");
+    public void invalidBuilder() {
+        ValidableTextField field = lookup("#field").queryAs(ValidableTextField.class);
         assertEquals(ValidationState.NOT_VALIDATED, field.getValidationState());
-        click(field).type("Chuck").push(KeyCode.ENTER);
-        FXTestUtils.invokeAndWait(() -> victim.getBuilder(onError), 1);
+        clickOn(field).write("Chuck").push(KeyCode.ENTER);
+        victim.getBuilder(onError);
         verify(onError).accept(anyString());
     }
 
     @Test
     public void builder() throws Exception {
-        ValidableTextField field = find("#field");
-        SplitByEveryRadioButton victim = find("#victim");
+        ValidableTextField field = lookup("#field").queryAs(ValidableTextField.class);
         assertEquals(ValidationState.NOT_VALIDATED, field.getValidationState());
-        click(field).type("6").push(KeyCode.ENTER);
+        clickOn(field).type(KeyCode.DIGIT6).push(KeyCode.ENTER);
         final File file = folder.newFile("my.pdf");
-        FXTestUtils.invokeAndWait(() -> {
-            SplitByEveryXPagesParametersBuilder builder = victim.getBuilder(onError);
-            builder.compress(true);
-            FileOrDirectoryTaskOutput output = mock(FileOrDirectoryTaskOutput.class);
-            builder.output(output);
-            builder.existingOutput(ExistingOutputPolicy.OVERWRITE);
-            builder.prefix("prefix");
-            PdfFileSource source = PdfFileSource.newInstanceNoPassword(file);
-            builder.source(source);
-            builder.version(PdfVersion.VERSION_1_7);
-            SplitByEveryXPagesParameters params = builder.build();
-            assertTrue(params.isCompress());
-            assertEquals(ExistingOutputPolicy.OVERWRITE, params.getExistingOutputPolicy());
-            assertEquals(PdfVersion.VERSION_1_7, params.getVersion());
-            assertThat(params.getPages(20), contains(6, 12, 18));
-            assertEquals("prefix", params.getOutputPrefix());
-            assertEquals(output, params.getOutput());
-            assertEquals(source, params.getSourceList().get(0));
-            verify(onError, never()).accept(anyString());
-        } , 2);
+        SplitByEveryXPagesParametersBuilder builder = victim.getBuilder(onError);
+        builder.compress(true);
+        FileOrDirectoryTaskOutput output = mock(FileOrDirectoryTaskOutput.class);
+        builder.output(output);
+        builder.existingOutput(ExistingOutputPolicy.OVERWRITE);
+        builder.prefix("prefix");
+        PdfFileSource source = PdfFileSource.newInstanceNoPassword(file);
+        builder.source(source);
+        builder.version(PdfVersion.VERSION_1_7);
+        SplitByEveryXPagesParameters params = builder.build();
+        assertTrue(params.isCompress());
+        assertEquals(ExistingOutputPolicy.OVERWRITE, params.getExistingOutputPolicy());
+        assertEquals(PdfVersion.VERSION_1_7, params.getVersion());
+        assertThat(params.getPages(20), contains(6, 12, 18));
+        assertEquals("prefix", params.getOutputPrefix());
+        assertEquals(output, params.getOutput());
+        assertEquals(source, params.getSourceList().get(0));
+        verify(onError, never()).accept(anyString());
     }
 
     @Test
     public void saveStateSelected() {
-        SplitByEveryRadioButton victim = find("#victim");
-        click(victim);
-        click("#field").type("chuck");
+        clickOn(victim);
+        clickOn("#field").write("chuck");
         Map<String, String> data = new HashMap<>();
         victim.saveStateTo(data);
         assertTrue(Boolean.valueOf(data.get("splitByEvery")));
@@ -160,7 +154,6 @@ public class SplitByEveryRadioButtonTest extends GuiTest {
 
     @Test
     public void saveStateNotSelected() {
-        SplitByEveryRadioButton victim = find("#victim");
         Map<String, String> data = new HashMap<>();
         victim.saveStateTo(data);
         assertFalse(Boolean.valueOf(data.get("splitByEvery")));
@@ -168,13 +161,12 @@ public class SplitByEveryRadioButtonTest extends GuiTest {
     }
 
     @Test
-    public void restoreState() throws Exception {
-        SplitByEveryRadioButton victim = find("#victim");
-        ValidableTextField field = find("#field");
+    public void restoreState() {
+        ValidableTextField field = lookup("#field").queryAs(ValidableTextField.class);
         Map<String, String> data = new HashMap<>();
         data.put("splitByEvery", Boolean.TRUE.toString());
         data.put("splitByEvery.field", "chuck");
-        FXTestUtils.invokeAndWait(() -> victim.restoreStateFrom(data), 2);
+        victim.restoreStateFrom(data);
         assertTrue(victim.isSelected());
         assertEquals("chuck", field.getText());
     }
